@@ -1,9 +1,15 @@
 """Common response models."""
 
-from starlette.responses import JSONResponse
+from starlette.responses import JSONResponse, Response
 
 
 class GeoJSONResponse(JSONResponse):
     """GeoJSON Response."""
 
     media_type = "application/geo+json"
+
+
+class PNGResponse(Response):
+    """GeoJSON Response."""
+
+    media_type = "image/png"
